# aspire: Accelerated Sequential Posterior Inference via REuse

aspire is a framework for reusing existing posterior samples to obtain new results at a reduced code.

## Installation

aspire can be installed from PyPI using `pip`

```
pip install aspire-inference
```

**Important:** the name of `aspire` on PyPI is `aspire-inference` but once installed
the package can be imported and used as `aspire`.
